@@ -3,7 +3,7 @@
 
 
 package BeamerReveal::Log::Win32;
-our $VERSION = '20251231.1054'; # VERSION
+our $VERSION = '20251231.1112'; # VERSION
 
 use parent 'BeamerReveal::Log';
 use Carp;
@@ -19,7 +19,7 @@ sub new {
   eval { $self->_win_init(); 1 } or do {
     # fall back to Ansi if Win32 API not available;
     say STDERR "Warning: did not find Win32 API, reverting to ANSI API.\n" .
-      "Maybe the package is missing? Consider: issuing 'cpanm Win32::Console' in a (power) shell.";
+      "Maybe the package is missing? Consider issuing 'cpanm Win32::Console' in a (power) shell.";
     return BeamerReveal::Log::Ansi->new( @_ );
   };
   
@@ -69,8 +69,8 @@ sub _win_init {
   #$self->{WCON} = Win32::Console->new( Win32::Console::STD_OUTPUT_HANDLE() );
 
   open my $CON, '>:raw', 'CONOUT$'
-    or $self->fatal( 0, "Error: cant open CONOUT$: $!" );
-  my $h = Win32API::File::GetOSFHandle( fileno( $CONN ) );
+    or die( "Error: cannot open CONOUT$: $!" );
+  my $h = Win32API::File::GetOSFHandle( fileno( $CON ) );
   $self->{WCON} = Win32::Console->new( $h );
   
   # Cursor AFTER reserving lines; region starts N lines above current cursor
@@ -113,7 +113,7 @@ BeamerReveal::Log::Win32 - Log
 
 =head1 VERSION
 
-version 20251231.1054
+version 20251231.1112
 
 =head1 SYNOPSIS
 
